@@ -4,15 +4,18 @@
 #' corresponding (scaled) importance weights. 
 #' Probably mostly useful for comparing KFAS and bssm packages.
 #' 
-#' 
 #' @inheritParams gaussian_approx
 #' @param model Model of class \code{bsm_ng}, \code{ar1_ng} \code{svm}, 
 #' \code{ssm_ung}, or \code{ssm_mng}.
-#' @param nsim Number of samples (positive integer).
+#' @param nsim Number of samples (positive integer). Suitable values 
+#' depend on the model and the data, and while larger values provide more 
+#' accurate estimates, the run time also increases with respect to to the 
+#' number of samples, so it is generally a good idea to test the filter first 
+#' with a small number of samples, e.g., less than 100.
 #' @param use_antithetic Logical. If \code{TRUE} (default), use antithetic 
 #' variable for location in simulation smoothing. Ignored for \code{ssm_mng} 
 #' models.
-#' @param seed Seed for the random number generator (positive integer).
+#' @param seed Seed for the C++ RNG (positive integer).
 #' @param ... Ignored.
 #' @export
 #' @rdname importance_sample
@@ -26,8 +29,8 @@
 #' 
 #' est <- matrix(NA, 3, nrow(sexratio))
 #' for(i in 1:ncol(est)) {
-#'   est[, i] <- Hmisc::wtd.quantile(exp(imp$alpha[i, 1, ]), imp$weights, 
-#'     prob = c(0.05,0.5,0.95), normwt=TRUE)
+#'   est[, i] <- diagis::weighted_quantile(exp(imp$alpha[i, 1, ]), imp$weights, 
+#'     prob = c(0.05,0.5,0.95))
 #' }
 #' 
 #' ts.plot(t(est),lty = c(2,1,2))
@@ -42,10 +45,12 @@ importance_sample <- function(model, nsim, use_antithetic,
 importance_sample.nongaussian <- function(model, nsim, use_antithetic = TRUE, 
   max_iter = 100, conv_tol = 1e-8, 
   seed = sample(.Machine$integer.max, size = 1), ...) {
-
-  model$max_iter <- check_integer(max_iter, "max_iter", positive = FALSE)
+  
+  check_missingness(model)
+  
+  model$max_iter <- check_intmax(max_iter, "max_iter", positive = FALSE)
   model$conv_tol <- check_positive_real(conv_tol, "conv_tol")
-  nsim <- check_integer(nsim, "nsim")
+  nsim <- check_intmax(nsim, "nsim")
   
   nsamples <- ifelse(!is.null(nrow(model$y)), nrow(model$y), length(model$y)) * 
     length(model$a1) * nsim
@@ -53,7 +58,9 @@ importance_sample.nongaussian <- function(model, nsim, use_antithetic = TRUE,
     warning(paste("Trying to sample ", nsamples, 
       "values, you might run out of memory."))
   }
-  seed <- check_integer(seed, "seed", FALSE, max = .Machine$integer.max)
+  seed <- check_intmax(seed, "seed", FALSE, max = .Machine$integer.max)
+  if (!test_flag(use_antithetic)) 
+    stop("Argument 'use_antithetic' should be TRUE or FALSE. ")
   model$distribution <- pmatch(model$distribution,
     c("svm", "poisson", "binomial", "negative binomial", "gamma", "gaussian"), 
     duplicates.ok = TRUE) - 1
