@@ -5,18 +5,20 @@
 #' 
 #' @inheritParams particle_smoother
 #' @param object Model of class \code{bssm_model}.
-#' @param particles Number of samples for particle filter. If 0, 
-#' approximate log-likelihood is returned either based on the Gaussian 
-#' approximation or EKF, depending on the \code{method} argument.
+#' @param particles Number of samples for particle filter 
+#' (non-negative integer). If 0, approximate log-likelihood is returned either 
+#' based on the Gaussian approximation or EKF, depending on the \code{method} 
+#' argument.
 #' @param method Sampling method. For Gaussian and non-Gaussian models with 
 #' linear dynamics,options are \code{"bsf"} (bootstrap particle filter, default 
-#' for non-linear models) 
-#' and \code{"psi"} (\eqn{\psi}-APF, the default for other models). 
-#' For-nonlinear models option \code{"ekf"} uses EKF/IEKF-based particle 
-#' filter (or just EKF/IEKF approximation in the case of \code{particles = 0}).
+#' for non-linear models) and \code{"psi"} (\eqn{\psi}-APF, the default for 
+#' other models). For-nonlinear models option \code{"ekf"} 
+#' uses EKF/IEKF-based particle filter (or just EKF/IEKF approximation in the 
+#' case of \code{particles = 0}).
 #' @importFrom stats logLik
-#' @method logLik gaussian
+#' @method logLik lineargaussian
 #' @rdname logLik_bssm
+#' @return A numeric value.
 #' @seealso particle_smoother
 #' @export
 #' @references
@@ -47,7 +49,10 @@
 #' @examples  
 #' model <- ssm_ulg(y = c(1,4,3), Z = 1, H = 1, T = 1, R = 1)
 #' logLik(model)
-logLik.gaussian <- function(object, ...) {
+logLik.lineargaussian <- function(object, ...) {
+  
+     check_missingness(object)
+  
   gaussian_loglik(object, model_type(object))
 }
 
@@ -69,8 +74,10 @@ logLik.nongaussian <- function(object, particles, method = "psi",
   max_iter = 100, conv_tol = 1e-8, 
   seed = sample(.Machine$integer.max, size = 1), ...) {
   
-  object$max_iter <- max_iter
-  object$conv_tol <- conv_tol
+     check_missingness(object)
+  
+  object$max_iter <- check_intmax(max_iter, "max_iter", positive = FALSE)
+  object$conv_tol <- check_positive_real(conv_tol, "conv_tol")
   
   if (missing(particles)) {
     nsim <- eval(match.call(expand.dots = TRUE)$nsim)
@@ -81,7 +88,7 @@ logLik.nongaussian <- function(object, particles, method = "psi",
     }
   }
   
-  method <- match.arg(method, c("psi", "bsf", "spdk"))
+  method <- match.arg(tolower(method), c("psi", "bsf", "spdk"))
   method <- pmatch(method, c("psi", "bsf", "spdk"))
   if (method == 2 && particles == 0) 
     stop("'particles' must be positive for bootstrap filter.")
@@ -99,6 +106,8 @@ logLik.ssm_nlg <- function(object, particles, method = "bsf",
   max_iter = 100, conv_tol = 1e-8, iekf_iter = 0,
   seed = sample(.Machine$integer.max, size = 1), ...) {
   
+     check_missingness(object)
+  
   if (missing(particles)) {
     nsim <- eval(match.call(expand.dots = TRUE)$nsim)
     if (!is.null(nsim)) {
@@ -110,10 +119,13 @@ logLik.ssm_nlg <- function(object, particles, method = "bsf",
   
   method <- match.arg(method, c("psi", "bsf", "ekf"))
   if (method == "bsf" && particles == 0) 
-    stop("'particles' must be positive for bootstrap particle filter.")
+    stop("'particles' must be positive for bootstrap filter.")
   method <- pmatch(method,  c("psi", "bsf", NA, "ekf"))
  
-  seed <- check_integer(seed, "seed", FALSE, max = .Machine$integer.max)
+  max_iter <- check_intmax(max_iter, "max_iter", positive = FALSE)
+  conv_tol <- check_positive_real(conv_tol, "conv_tol")
+  iekf_iter <- check_intmax(iekf_iter, "iekf_iter", positive = FALSE)
+  seed <- check_intmax(seed, "seed", FALSE, max = .Machine$integer.max)
   
   nonlinear_loglik(t(object$y), object$Z, object$H, object$T, 
     object$R, object$Z_gn, object$T_gn, object$a1, object$P1, 
@@ -128,6 +140,9 @@ logLik.ssm_nlg <- function(object, particles, method = "bsf",
 #' @export
 logLik.ssm_sde <- function(object, particles, L,
   seed = sample(.Machine$integer.max, size = 1), ...) {
+  
+     check_missingness(object)
+  
   if (L <= 0) stop("Discretization level L must be larger than 0.")
   if (missing(particles)) {
     nsim <- eval(match.call(expand.dots = TRUE)$nsim)
@@ -137,7 +152,8 @@ logLik.ssm_sde <- function(object, particles, L,
       particles <- nsim
     }
   }
-  seed <- check_integer(seed, "seed", FALSE, max = .Machine$integer.max)
+  seed <- check_intmax(seed, "seed", FALSE, max = .Machine$integer.max)
+  
   loglik_sde(object$y, object$x0, object$positive, 
     object$drift, object$diffusion, object$ddiffusion, 
     object$prior_pdf, object$obs_pdf, object$theta, 
