@@ -463,8 +463,7 @@ Rcpp::List bsf_nlg(const arma::mat& y, SEXP Z, SEXP H,
   const arma::vec& theta, SEXP log_prior_pdf, const arma::vec& known_params,
   const arma::mat& known_tv_params, const unsigned int n_states,
   const unsigned int n_etas,  const arma::uvec& time_varying,
-  const unsigned int nsim, const unsigned int seed,
-  const Rcpp::Function update_fn, const Rcpp::Function prior_fn) {
+  const unsigned int nsim, const unsigned int seed) {
   
   
   Rcpp::XPtr<nvec_fnPtr> xpfun_Z(Z);
@@ -479,7 +478,7 @@ Rcpp::List bsf_nlg(const arma::mat& y, SEXP Z, SEXP H,
   
   ssm_nlg model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg,
     *xpfun_a1, *xpfun_P1,  theta, *xpfun_prior, known_params, known_tv_params, n_states, n_etas,
-    time_varying, update_fn, prior_fn, seed);
+    time_varying, seed);
   
   unsigned int m = model.m;
   unsigned n = model.n;
@@ -512,8 +511,7 @@ Rcpp::List bsf_smoother_nlg(const arma::mat& y, SEXP Z, SEXP H,
   const arma::vec& theta, SEXP log_prior_pdf, const arma::vec& known_params,
   const arma::mat& known_tv_params, const unsigned int n_states,
   const unsigned int n_etas,  const arma::uvec& time_varying,
-  const unsigned int nsim, const unsigned int seed,
-  const Rcpp::Function update_fn, const Rcpp::Function prior_fn) {
+  const unsigned int nsim, const unsigned int seed) {
   
   
   Rcpp::XPtr<nvec_fnPtr> xpfun_Z(Z);
@@ -528,7 +526,7 @@ Rcpp::List bsf_smoother_nlg(const arma::mat& y, SEXP Z, SEXP H,
   
   ssm_nlg model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg,
     *xpfun_a1, *xpfun_P1,  theta, *xpfun_prior, known_params, known_tv_params, n_states, n_etas,
-    time_varying, update_fn, prior_fn, seed);
+    time_varying, seed);
   
   unsigned int m = model.m;
   unsigned n = model.n;
