@@ -3,6 +3,8 @@
 
 #include "model_ssm_ung.h"
 
+extern Rcpp::Function default_prior_fn;
+
 class bsm_ng: public ssm_ung {
 
 public:
@@ -11,7 +13,9 @@ public:
 
   // update model given the parameters theta
   void update_model(const arma::vec& new_theta);
-  double log_prior_pdf(const arma::vec& x) const;
+  void update_model(const arma::vec& new_theta, const Rcpp::Function update_fn);
+  
+  double log_prior_pdf(const arma::vec& x, const Rcpp::Function prior_fn = default_prior_fn) const;
   
 private:
   const arma::uvec prior_distributions;
